@@ -30,7 +30,7 @@ module Vagrant
           return true
         end
       rescue Timeout::Error, Errno::ECONNREFUSED, Errno::EHOSTUNREACH, \
-             Errno::ENETUNREACH, Errno::EACCES
+             Errno::ENETUNREACH, Errno::EACCES, Errno::ENOTCONN
         # Any of the above exceptions signal that the port is closed.
         return false
       end
