@@ -335,8 +335,8 @@ module VagrantPlugins
           forward_agent:         ssh_info[:forward_agent],
           send_env:              ssh_info[:forward_env],
           keys:                  ssh_info[:private_key_path],
-          keys_only:             true,
-          paranoid:              false,
+          keys_only:             ssh_info[:keys_only],
+          paranoid:              ssh_info[:paranoid],
           password:              ssh_info[:password],
           port:                  ssh_info[:port],
           timeout:               15,
