@@ -54,20 +54,21 @@ module VagrantPlugins
       end
 
       def powershell(command, &block)
-        # Suppress the progress stream from leaking to stderr
-        command = "$ProgressPreference='SilentlyContinue';\r\n" + command
-        command << "\r\n"
         # Ensure an exit code
-        command << "if ($?) { exit 0 } else { if($LASTEXITCODE) { exit $LASTEXITCODE } else { exit 1 } }"
-        execute_shell(command, :powershell, &block)
+        command += "\r\nif ($?) { exit 0 } else { if($LASTEXITCODE) { exit $LASTEXITCODE } else { exit 1 } }"
+        execute_with_rescue(executor.method("run_powershell_script"), command, &block)
       end
 
       def cmd(command, &block)
-        execute_shell(command, :cmd, &block)
+        execute_with_rescue(executor.method("run_cmd"), command, &block)
       end
 
       def wql(query, &block)
-        execute_shell(query, :wql, &block)
+        retryable(tries: @config.max_tries, on: @@exceptions_to_retry_on, sleep: @config.retry_delay) do
+          handle_output(session.method("run_wql"), query, &block)
+        end
+      rescue => e
+        raise_winrm_exception(e, "run_wql", query)
       end
 
       def upload(from, to)
@@ -82,42 +83,35 @@ module VagrantPlugins
 
       protected
 
-      def execute_shell(command, shell=:powershell, &block)
-        raise Errors::WinRMInvalidShell, shell: shell unless [:powershell, :cmd, :wql].include?(shell)
-
-        begin
-          execute_shell_with_retry(command, shell, &block)
-        rescue => e
-          raise_winrm_exception(e, shell, command)
-        end
+      def execute_with_rescue(method, command, &block)
+        handle_output(method, command, &block)
+      rescue => e
+        raise_winrm_exception(e, method.name, command)
       end
 
-      def execute_shell_with_retry(command, shell, &block)
-        retryable(tries: @config.max_tries, on: @@exceptions_to_retry_on, sleep: @config.retry_delay) do
-          @logger.debug("#{shell} executing:\n#{command}")
-          output = session.send(shell, command) do |out, err|
-            block.call(:stdout, out) if block_given? && out
-            block.call(:stderr, err) if block_given? && err
-          end
+      def handle_output(execute_method, command, &block)
+        output = execute_method.call(command) do |out, err|
+          block.call(:stdout, out) if block_given? && out
+          block.call(:stderr, err) if block_given? && err
+        end
 
-          @logger.debug("Output: #{output.inspect}")
+        @logger.debug("Output: #{output.inspect}")
 
-          # Verify that we didn't get a parser error, and if so we should
-          # set the exit code to 1. Parse errors return exit code 0 so we
-          # need to do this.
-          if output[:exitcode] == 0
-            (output[:data] || []).each do |data|
-              next if !data[:stderr]
-              if data[:stderr].include?("ParserError")
-                @logger.warn("Detected ParserError, setting exit code to 1")
-                output[:exitcode] = 1
-                break
-              end
+        # Verify that we didn't get a parser error, and if so we should
+        # set the exit code to 1. Parse errors return exit code 0 so we
+        # need to do this.
+        if output[:exitcode] == 0
+          (output[:data] || []).each do |data|
+            next if !data[:stderr]
+            if data[:stderr].include?("ParserError")
+              @logger.warn("Detected ParserError, setting exit code to 1")
+              output[:exitcode] = 1
+              break
             end
           end
-
-          return output
         end
+
+        return output
       end
 
       def raise_winrm_exception(exception, shell = nil, command = nil)
@@ -170,7 +164,7 @@ module VagrantPlugins
 
         client = ::WinRM::WinRMWebService.new(endpoint, @config.transport.to_sym, endpoint_options)
         client.set_timeout(@config.timeout)
-        client.toggle_nori_type_casting(:off) #we don't want coersion of types
+        client.logger = @logger
         client
       end
 
@@ -178,11 +172,15 @@ module VagrantPlugins
         @session ||= new_session
       end
 
+      def executor
+        @executor ||= session.create_executor
+      end
+
       def endpoint
         case @config.transport.to_sym
         when :ssl
           "https://#{@host}:#{@port}/wsman"
-        when :plaintext
+        when :plaintext, :negotiate
           "http://#{@host}:#{@port}/wsman"
         else
           raise Errors::WinRMInvalidTransport, transport: @config.transport
@@ -194,8 +192,10 @@ module VagrantPlugins
           pass: @password,
           host: @host,
           port: @port,
-          basic_auth_only: true,
-          no_ssl_peer_verification: !@config.ssl_peer_verification }
+          basic_auth_only: @config.basic_auth_only,
+          no_ssl_peer_verification: !@config.ssl_peer_verification,
+          retry_delay: @config.retry_delay,
+          retry_limit: @config.max_tries }
       end
     end #WinShell class
   end
