@@ -5,13 +5,12 @@ module VagrantPlugins
         def self.flavor(machine)
           # Read the version file
           output = ""
-          machine.communicate.sudo("cat /etc/redhat-release") do |type, data|
-            output += data if type == :stdout
+          machine.communicate.sudo("cat /etc/redhat-release") do |_, data|
+            output = data
           end
-          output.chomp!
 
           # Detect various flavors we care about
-          if output =~ /(CentOS|Red Hat Enterprise|Scientific) Linux( .+)? release 7/i
+          if output =~ /(CentOS|Red Hat Enterprise|Scientific|Cloud)\s*Linux( .+)? release 7/i
             return :rhel_7
           else
             return :rhel
