@@ -69,14 +69,14 @@ describe Vagrant::Environment do
 
   describe "#home_path" do
     it "is set to the home path given" do
-      temporary_dir do |dir|
+      Dir.mktmpdir("vagrant-test-env-home-path-given") do |dir|
         instance = described_class.new(home_path: dir)
         expect(instance.home_path).to eq(Pathname.new(dir))
       end
     end
 
     it "is set to the environmental variable VAGRANT_HOME" do
-      temporary_dir do |dir|
+      Dir.mktmpdir("vagrant-test-env-home-env-var") do |dir|
         instance = with_temp_env("VAGRANT_HOME" => dir.to_s) do
           described_class.new
         end
@@ -99,7 +99,7 @@ describe Vagrant::Environment do
       end
 
       it "is okay if it has the current version" do
-        Dir.mktmpdir do |dir|
+        Dir.mktmpdir("vagrant-test-env-current-version") do |dir|
           Pathname.new(dir).join("setup_version").open("w") do |f|
             f.write(Vagrant::Environment::CURRENT_SETUP_VERSION)
           end
@@ -112,7 +112,7 @@ describe Vagrant::Environment do
       end
 
       it "raises an exception if the version is newer than ours" do
-        Dir.mktmpdir do |dir|
+        Dir.mktmpdir("vagrant-test-env-newer-version") do |dir|
           Pathname.new(dir).join("setup_version").open("w") do |f|
             f.write("100.5")
           end
@@ -123,7 +123,7 @@ describe Vagrant::Environment do
       end
 
       it "raises an exception if there is an unknown home directory version" do
-        Dir.mktmpdir do |dir|
+        Dir.mktmpdir("vagrant-test-env-unknown-home") do |dir|
           Pathname.new(dir).join("setup_version").open("w") do |f|
             f.write("0.7")
           end
@@ -645,7 +645,7 @@ VF
 
   describe "active machines" do
     it "should be empty if there is no root path" do
-      Dir.mktmpdir do |temp_dir|
+      Dir.mktmpdir("vagrant-test-env-no-root-path") do |temp_dir|
         instance = described_class.new(cwd: temp_dir)
         expect(instance.active_machines).to be_empty
       end
@@ -715,7 +715,7 @@ VF
 
   describe "current working directory" do
     it "is the cwd by default" do
-      Dir.mktmpdir do |temp_dir|
+      Dir.mktmpdir("vagrant-test-env-cwd-default") do |temp_dir|
         Dir.chdir(temp_dir) do
           with_temp_env("VAGRANT_CWD" => nil) do
             expect(described_class.new.cwd).to eq(Pathname.new(Dir.pwd))
@@ -725,14 +725,14 @@ VF
     end
 
     it "is set to the cwd given" do
-      Dir.mktmpdir do |directory|
+      Dir.mktmpdir("vagrant-test-env-set-cwd") do |directory|
         instance = described_class.new(cwd: directory)
         expect(instance.cwd).to eq(Pathname.new(directory))
       end
     end
 
     it "is set to the environmental variable VAGRANT_CWD" do
-      Dir.mktmpdir do |directory|
+      Dir.mktmpdir("vagrant-test-env-set-vagrant-cwd") do |directory|
         instance = with_temp_env("VAGRANT_CWD" => directory) do
           described_class.new
         end
@@ -905,7 +905,7 @@ VF
     end
 
     it "is expanded relative to the cwd" do
-      Dir.mktmpdir do |temp_dir|
+      Dir.mktmpdir("vagrant-test-env-relative-cwd") do |temp_dir|
         Dir.chdir(temp_dir) do
           instance = described_class.new(local_data_path: "foo")
           expect(instance.local_data_path).to eq(instance.cwd.join("foo"))
@@ -915,7 +915,7 @@ VF
     end
 
     it "is set to the given value" do
-      Dir.mktmpdir do |dir|
+      Dir.mktmpdir("vagrant-test-env-set-given") do |dir|
         instance = described_class.new(local_data_path: dir)
         expect(instance.local_data_path.to_s).to eq(dir)
       end
@@ -923,7 +923,7 @@ VF
 
     describe "upgrading V1 dotfiles" do
       let(:v1_dotfile_tempfile) do
-        Tempfile.new("vagrant").tap do |f|
+        Tempfile.new("vagrant-upgrade-dotfile").tap do |f|
           f.close
         end
       end
@@ -932,6 +932,10 @@ VF
       let(:local_data_path)     { v1_dotfile_tempfile.path }
       let(:instance) { described_class.new(local_data_path: local_data_path) }
 
+      after do
+        FileUtils.rm_rf(local_data_path)
+      end
+
       it "should be fine if dotfile is empty" do
         v1_dotfile.open("w+") do |f|
           f.write("")
